@@ -97,10 +97,7 @@ class SPIRVTypeBufferSurfaceINTEL;
 class SPIRVTypeTokenINTEL;
 class SPIRVTypeJointMatrixINTEL;
 class SPIRVTypeCooperativeMatrixKHR;
-class SPIRVConditionalCapabilityINTEL;
-class SPIRVConditionalExtensionINTEL;
-class SPIRVConditionalEntryPointINTEL;
-class SPIRVConditionalCopyObjectINTEL;
+class SPIRVTypeTaskSequenceINTEL;
 
 typedef SPIRVBasicBlock SPIRVLabel;
 struct SPIRVTypeImageDescriptor;
@@ -108,13 +105,6 @@ struct SPIRVTypeImageDescriptor;
 class SPIRVModule {
 public:
   typedef std::map<SPIRVCapabilityKind, SPIRVCapability *> SPIRVCapMap;
-  typedef std::map<std::pair<SPIRVId, SPIRVCapabilityKind>,
-                   SPIRVConditionalCapabilityINTEL *>
-      SPIRVConditionalCapMap;
-  typedef std::vector<SPIRVConditionalEntryPointINTEL *>
-      SPIRVConditionalEntryPointVec;
-  typedef std::set<std::pair<SPIRVId, std::string>>
-      SPIRVConditionalExtensionSet;
 
   static SPIRVModule *createSPIRVModule();
   static SPIRVModule *createSPIRVModule(const SPIRV::TranslatorOpts &);
@@ -143,22 +133,14 @@ public:
   // Module query functions
   virtual SPIRVAddressingModelKind getAddressingModel() = 0;
   virtual const SPIRVCapMap &getCapability() const = 0;
-  virtual const SPIRVConditionalCapMap &getConditionalCapabilities() const = 0;
-  virtual const SPIRVConditionalEntryPointVec &
-  getConditionalEntryPoints() const = 0;
   virtual bool hasCapability(SPIRVCapabilityKind) const = 0;
   virtual SPIRVExtInstSetKind getBuiltinSet(SPIRVId) const = 0;
   virtual std::set<std::string> &getExtension() = 0;
-  virtual SPIRVConditionalExtensionSet &getConditionalExtensions() = 0;
   virtual SPIRVFunction *getFunction(unsigned) const = 0;
   virtual SPIRVVariable *getVariable(unsigned) const = 0;
-  virtual SPIRVValue *getConst(unsigned) const = 0;
-  virtual std::vector<SPIRVDecorateGeneric *> *getDecorateVec() = 0;
-  virtual std::vector<SPIRVFunction *> *getFuncVec() = 0;
   virtual SPIRVMemoryModelKind getMemoryModel() const = 0;
   virtual unsigned getNumFunctions() const = 0;
   virtual unsigned getNumVariables() const = 0;
-  virtual unsigned getNumConsts() const = 0;
   virtual std::vector<SPIRVValue *> getFunctionPointers() const = 0;
   virtual SourceLanguage getSourceLanguage(SPIRVWord *) const = 0;
   virtual std::set<std::string> &getSourceExtension() = 0;
@@ -176,7 +158,7 @@ public:
   virtual bool isEntryPoint(SPIRVExecutionModelKind, SPIRVId) const = 0;
   virtual unsigned short getGeneratorId() const = 0;
   virtual unsigned short getGeneratorVer() const = 0;
-  virtual SPIRVWord getSPIRVVersion() const = 0;
+  virtual VersionNumber getSPIRVVersion() const = 0;
   virtual const std::vector<SPIRVExtInst *> &getDebugInstVec() const = 0;
   virtual const std::vector<SPIRVExtInst *> &getAuxDataInstVec() const = 0;
 
@@ -196,17 +178,15 @@ public:
   virtual void setGeneratorId(unsigned short) = 0;
   virtual void setGeneratorVer(unsigned short) = 0;
   virtual void resolveUnknownStructFields() = 0;
-  virtual void setSPIRVVersion(SPIRVWord) = 0;
+  virtual void setSPIRVVersion(VersionNumber) = 0;
   virtual void insertEntryNoId(SPIRVEntry *Entry) = 0;
-  virtual bool eraseReferencesOfInst(SPIRVId Id) = 0;
-  virtual void eraseCapability(SPIRVCapabilityKind CapKind) = 0;
 
   void setMinSPIRVVersion(VersionNumber Ver) {
-    setSPIRVVersion(std::max(static_cast<SPIRVWord>(Ver), getSPIRVVersion()));
+    setSPIRVVersion(std::max(Ver, getSPIRVVersion()));
   }
 
   void setMaxSPIRVVersion(VersionNumber Ver) {
-    assert(static_cast<SPIRVWord>(Ver) >= getSPIRVVersion() &&
+    assert(Ver >= getSPIRVVersion() &&
            "Maximum version can't be lower than minimum version!");
     MaxVersion = std::min(Ver, MaxVersion);
   }
@@ -252,10 +232,6 @@ public:
   virtual void addEntryPoint(SPIRVExecutionModelKind, SPIRVId,
                              const std::string &,
                              const std::vector<SPIRVId> &) = 0;
-  virtual void addConditionalEntryPoint(SPIRVId, SPIRVExecutionModelKind,
-                                        SPIRVId, const std::string &,
-                                        const std::vector<SPIRVId> &) = 0;
-  virtual void specializeConditionalEntryPoints(SPIRVId, bool) = 0;
   virtual SPIRVForward *addForward(SPIRVType *Ty) = 0;
   virtual SPIRVForward *addForward(SPIRVId, SPIRVType *Ty) = 0;
   virtual SPIRVFunction *addFunction(SPIRVFunction *) = 0;
@@ -263,10 +239,9 @@ public:
                                      SPIRVId Id = SPIRVID_INVALID) = 0;
   virtual SPIRVEntry *replaceForward(SPIRVForward *, SPIRVEntry *) = 0;
   virtual void eraseInstruction(SPIRVInstruction *, SPIRVBasicBlock *) = 0;
-  virtual bool eraseValue(SPIRVValue *) = 0;
 
   // Type creation functions
-  virtual SPIRVTypeArray *addArrayType(SPIRVType *, SPIRVConstant *) = 0;
+  virtual SPIRVTypeArray *addArrayType(SPIRVType *, SPIRVValue *) = 0;
   virtual SPIRVTypeBool *addBoolType() = 0;
   virtual SPIRVTypeFloat *addFloatType(unsigned, unsigned = FPEncodingMax) = 0;
   virtual SPIRVTypeFunction *
@@ -291,6 +266,9 @@ public:
   addJointMatrixINTELType(SPIRVType *, std::vector<SPIRVValue *>) = 0;
   virtual SPIRVTypeCooperativeMatrixKHR *
   addCooperativeMatrixKHRType(SPIRVType *, std::vector<SPIRVValue *>) = 0;
+  virtual SPIRVTypeTaskSequenceINTEL *addTaskSequenceINTELType() = 0;
+  virtual SPIRVInstruction *
+  addTaskSequenceGetINTELInst(SPIRVType *, SPIRVValue *, SPIRVBasicBlock *) = 0;
   virtual SPIRVInstruction *
   addCooperativeMatrixLengthKHRInst(SPIRVType *, SPIRVType *,
                                     SPIRVBasicBlock *) = 0;
@@ -368,13 +346,6 @@ public:
     for (auto I : Caps)
       addCapability(I);
   }
-  virtual void addConditionalCapability(SPIRVId, SPIRVCapabilityKind) = 0;
-  template <typename T>
-  void addConditionalCapabilities(SPIRVId Condition, const T &Caps) {
-    for (auto I : Caps)
-      addConditionalCapability(Condition, I);
-  }
-  virtual void eraseConditionalCapability(SPIRVId, SPIRVCapabilityKind) = 0;
   virtual void addExtension(ExtensionID) = 0;
   /// Used by SPIRV entries to add required capability internally.
   /// Should not be used by users directly.
@@ -557,10 +528,6 @@ public:
     return TranslationOpts.getSpecializationConstant(SpecId, ConstValue);
   }
 
-  void setSpecializationConstant(SPIRVWord SpecId, uint64_t ConstValue) {
-    TranslationOpts.setSpecConst(SpecId, ConstValue);
-  }
-
   FPContractMode getFPContractMode() const {
     return TranslationOpts.getFPContractMode();
   }
@@ -613,33 +580,12 @@ public:
     return SPIRVEIS_Debug;
   }
 
+  ExtInst getExtInst() const { return TranslationOpts.getExtInst(); }
+
   BIsRepresentation getDesiredBIsRepresentation() const {
     return TranslationOpts.getDesiredBIsRepresentation();
   }
 
-  std::optional<uint32_t> getFnVarCategory() const {
-    return TranslationOpts.getFnVarCategory();
-  }
-  std::optional<uint32_t> getFnVarFamily() const {
-    return TranslationOpts.getFnVarFamily();
-  }
-  std::optional<uint32_t> getFnVarArch() const {
-    return TranslationOpts.getFnVarArch();
-  }
-  std::optional<uint32_t> getFnVarTarget() const {
-    return TranslationOpts.getFnVarTarget();
-  }
-  std::vector<uint32_t> getFnVarFeatures() const {
-    return TranslationOpts.getFnVarFeatures();
-  }
-  std::vector<uint32_t> getFnVarCapabilities() const {
-    return TranslationOpts.getFnVarCapabilities();
-  }
-
-  std::string getFnVarSpvOut() const {
-    return TranslationOpts.getFnVarSpvOut();
-  }
-
   // I/O functions
   friend spv_ostream &operator<<(spv_ostream &O, SPIRVModule &M);
   friend std::istream &operator>>(std::istream &I, SPIRVModule &M);
