@@ -330,11 +330,10 @@ _SPIRV_OP(GroupNonUniformBitwiseXor, 361)
 _SPIRV_OP(GroupNonUniformLogicalAnd, 362)
 _SPIRV_OP(GroupNonUniformLogicalOr, 363)
 _SPIRV_OP(GroupNonUniformLogicalXor, 364)
-_SPIRV_OP(CopyLogical, 400)
 _SPIRV_OP(PtrEqual, 401)
 _SPIRV_OP(PtrNotEqual, 402)
 _SPIRV_OP(PtrDiff, 403)
-_SPIRV_OP(FmaKHR, 4427)
+_SPIRV_OP(CopyLogical, 400)
 _SPIRV_OP(GroupNonUniformRotateKHR, 4431)
 _SPIRV_OP(SDotKHR, 4450)
 _SPIRV_OP(UDotKHR, 4451)
@@ -572,13 +571,6 @@ _SPIRV_OP(Subgroup2DBlockPrefetchINTEL, 6234)
 _SPIRV_OP(Subgroup2DBlockStoreINTEL, 6235)
 _SPIRV_OP(SubgroupMatrixMultiplyAccumulateINTEL, 6237)
 _SPIRV_OP(BitwiseFunctionINTEL, 6242)
-_SPIRV_OP(ConditionalExtensionINTEL, 6248)
-_SPIRV_OP(ConditionalEntryPointINTEL, 6249)
-_SPIRV_OP(ConditionalCapabilityINTEL, 6250)
-_SPIRV_OP(SpecConstantTargetINTEL, 6251)
-_SPIRV_OP(SpecConstantArchitectureINTEL, 6252)
-_SPIRV_OP(SpecConstantCapabilitiesINTEL, 6253)
-_SPIRV_OP(ConditionalCopyObjectINTEL, 6254)
 _SPIRV_OP(GroupIMulKHR, 6401)
 _SPIRV_OP(GroupFMulKHR, 6402)
 _SPIRV_OP(GroupBitwiseAndKHR, 6403)
